@@ -78,11 +78,11 @@ class RemoteTableDataStore(RemoteStore):
 
         return pd.DataFrame(table_result['rows'], columns=table_result['column_headers'])
 
-    def get_data_objects(self, parent: str, query: str = "*", document_family: Optional[DocumentFamily] = None):
+    def get_data_objects(self, path: str, query: str = "*", document_family: Optional[DocumentFamily] = None):
         """
 
         Args:
-          parent (str): The parent taxon (/ is root)
+          path (str): The path to the data object
           query (str): A query to limit the results (Default *)
           document_family (Optional[DocumentFamily): Optionally the document family to limit results to
         Returns:
@@ -91,47 +91,45 @@ class RemoteTableDataStore(RemoteStore):
 
         # We need to get the first set of rows,
         rows: List = []
-        row_response = self.get_parent_page_request(parent, 1, document_family=document_family)
+        row_response = self.get_data_objects_page_request(path, 1, document_family=document_family)
 
         # lets work out the last page
         rows = rows + row_response['content']
         total_pages = row_response['totalPages']
 
         for page in range(2, total_pages):
-            row_response = self.get_parent_page_request(parent, page, query=query, document_family=document_family)
+            row_response = self.get_data_objects_page_request(path, page, query=query, document_family=document_family)
             rows = rows + row_response['content']
 
-        # Once we have all the rows we will then get a list of all the columns
-        # and convert this into a more nature form for structured data
+        return rows
 
-        column_names: List[str] = []
-        for row in rows:
-            for key in row['data'].keys():
-                if key not in column_names:
-                    column_names.append(key)
+    def get_data_object(self, data_object_id: str):
+        from kodexa import KodexaPlatform
 
-        # Now lets get all the rows and make sure we put them in the same
-        # order as the columns
+        url = f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/dataObjects/{data_object_id}"
+        logger.info(f"Downloading a specific data object from {url}")
 
-        new_rows: List[List[str]] = []
+        data_object_response = requests.get(
+            url,
+            headers={"x-access-token": KodexaPlatform.get_access_token(), "content-type": "application/json"})
 
-        for row in rows:
-            new_row = []
-            for column_name in column_names:
-                new_row.append(row['data'].get(column_name, None))
-            new_rows.append(new_row)
+        print(data_object_response)
+        if data_object_response.status_code == 200:
+            return data_object_response.json()
+        else:
+            logger.warning(
+                "Unable to get data object from remote store [" + data_object_response.text + "], response " + str(
+                    data_object_response.status_code))
+            raise Exception(
+                "Unable to get data object from remote store  [" + data_object_response.text + "], response " + str(
+                    data_object_response.status_code))
 
-        return {
-            "columns": column_names,
-            "rows": new_rows
-        }
-
-    def get_parent_page_request(self, parent: str, page_number: int = 1, page_size=5000, query="*",
-                                document_family: Optional[DocumentFamily] = None):
+    def get_data_objects_page_request(self, path: str, page_number: int = 1, page_size=5000, query="*",
+                                      document_family: Optional[DocumentFamily] = None):
         """
 
         Args:
-          parent (str): The parent taxon (/ is root)
+          path (str): The parent taxon (/ is root)
           page_number (int):  (Default value = 1)
           page_size (int):  (Default value = 5000)
           query (str): The query to limit results (Default *)
@@ -146,7 +144,7 @@ class RemoteTableDataStore(RemoteStore):
         logger.debug(f"Downloading a specific table from {url}")
 
         # We need to go through and pull all the pages
-        params = {"parent": parent, "page": page_number, "pageSize": page_size, "query": query}
+        params = {"path": path, "page": page_number, "pageSize": page_size, "query": query}
 
         if document_family:
             params['documentFamilyId'] = document_family.id
@@ -165,6 +163,7 @@ class RemoteTableDataStore(RemoteStore):
             raise Exception("Unable to get table from remote store  [" + rows_response.text + "], response " + str(
                 rows_response.status_code))
 
+
     def add_rows(self, rows):
         """
 
